/**
 *  Copyright (c) 1997-2013, tinygroup.org (luo_guo@live.cn).
 *
 *  Licensed under the GPL, Version 3.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *       http://www.gnu.org/licenses/gpl.html
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 * --------------------------------------------------------------------------
 *  版权 (c) 1997-2013, tinygroup.org (luo_guo@live.cn).
 *
 *  本开源软件遵循 GPL 3.0 协议;
 *  如果您不遵循此协议，则不被允许使用此文件。
 *  你可以从下面的地址获取完整的协议文本
 *
 *       http://www.gnu.org/licenses/gpl.html
 */
package org.tinygroup.noderoute;

/**
 * 路由节点
 * @author luoguo
 *
 */
public final class Node implements Comparable<Node> {
	
	/**
	 * 分组名
	 */
	private String groupName;
	/**
	 * 节点名
	 */
	private String nodeName;
	/**
	 * 分配比例，ratable/(同一分组名下的节点的ratable的总和)
	 */
	private int ratable;

	public Node() {
	}

	public Node(String groupName, String nodeName, int ratable) {
		this.groupName = groupName;
		this.nodeName = nodeName;
		this.ratable = ratable;
	}

	public int getRatable() {
		return ratable;
	}

	public String getName() {
		if (groupName == null) {
			return nodeName;
		} else {
			return String.format("%s:%s", groupName, nodeName);
		}
	}

	public void setRatable(int ratable) {
		this.ratable = ratable;
	}

	public String getGroupName() {
		return groupName;
	}

	public void setGroupName(String groupName) {
		this.groupName = groupName;
	}

	public String getNodeName() {
		return nodeName;
	}

	public void setNodeName(String nodeName) {
		this.nodeName = nodeName;
	}

	/**
	 * 比较节点名称
	 */
	public int compareTo(Node node) {
		int groupNameCompare = groupName.compareTo(node.groupName);
		if (groupNameCompare != 0) {
			return groupNameCompare;
		}
		return nodeName.compareTo(node.nodeName);
	}

}
